==> openGion_core_5.9.17.1.zip: ge/db/sqlserver/sql/install/01_TABLE/GE39S.sql <==
/****************************************************************************/
/* GE39 ( ﾌｧｲﾙ管理ﾃｰﾌﾞﾙ )                                                   */
/*                                                                          */
/* Created : 2016/11/04 10:32:19                                            */
/****************************************************************************/
CREATE TABLE GE39 (
   UNIQ_ID      varchar           (   10 )                  NOT NULL            /*  10 UNIQ番号     */
 , SEQNO        INTEGER                         DEFAULT 0   NOT NULL            /*  20 表示順       */
 , SYSTEM_ID    varchar           (   10 )                  NOT NULL            /*  30 ｼｽﾃﾑID       */
 , SYFILE       varchar           (  100 )                  NOT NULL            /*  40 ﾌｧｲﾙ種別     */
 , REF_KEY      varchar           (  100 )                  NOT NULL            /*  50 関連ｷｰ       */
 , SUFFIX       varchar           (   10 )                                      /*  60 拡張子       */
 , SYNAME       varchar           (  200 )                                      /*  70 種別名称     */
 , SAVE_FOLDER  varchar           (  300 )                                      /*  80 保管ﾌｫﾙﾀﾞ    */
 , FILE_URL     varchar           (  300 )                                      /*  90 ﾌｧｲﾙURL      */
 , ICON_URL     varchar           (  300 )                                      /* 100 ｱｲｺﾝURL      */
 , ROLES        varchar           (  500 )                                      /* 110 ﾛｰﾙｽﾞ        */
 , SU_LMT       INTEGER                         DEFAULT 0   NOT NULL            /* 120 閲覧制限数   */
 , DY_LMT       INTEGER                         DEFAULT 0   NOT NULL            /* 130 閲覧期日     */
 , FGANGO       varchar           (    1 )      DEFAULT 0   NOT NULL            /* 140 暗号化FG     */
 , FGZIP        varchar           (    1 )      DEFAULT 0   NOT NULL            /* 150 圧縮FG       */
 , FILE_NAME    varchar           (  500 )                                      /* 160 ﾌｧｲﾙ名称     */
 , CONTENTS     varchar           ( 4000 )                                      /* 170 内容         */
 , FG_NEW       varchar           (    1 )      DEFAULT 1   NOT NULL            /* 180 最新FG       */
 , SIZE_FILE    INTEGER                         DEFAULT 0   NOT NULL            /* 190 ﾌｧｲﾙｻｲｽﾞ     */
 , DYFILESET    varchar           (   14 )                                      /* 200 ﾌｧｲﾙ登録日時 */
 , USRTOROKU    varchar           (   10 )                                      /* 210 ﾌｧｲﾙ登録者   */
 , SETGUIID     varchar           (   10 )                                      /* 220 登録画面ID   */
 , FGKOSHIN     varchar           (    1 )      DEFAULT 1                       /* 230 変更許可FG   */
 , FGKOKAI      varchar           (    1 )      DEFAULT 1                       /* 240 公開許可FG   */
 , SRCHKEY1     varchar           (  500 )                                      /* 250 検索ｷｰ1      */
 , SRCHKEY2     varchar           (  500 )                                      /* 270 検索ｷｰ2      */
 , SRCHKEY3     varchar           (  500 )                                      /* 280 検索ｷｰ3      */
 , SRCHKEY4     varchar           (  500 )                                      /* 290 検索ｷｰ4      */
 , SRCHKEY5     varchar           (  500 )                                      /* 300 検索ｷｰ5      */
 , SRCHKEY6     varchar           (  500 )                                      /* 310 検索ｷｰ6      */
 , SRCHKEY7     varchar           (  500 )                                      /* 320 検索ｷｰ7      */
 , SRCHKEY8     varchar           (  500 )                                      /* 330 検索ｷｰ8      */
 , SRCHKEY9     varchar           (  500 )                                      /* 340 検索ｷｰ9      */
 , SRCHKEY10    varchar           (  500 )                                      /* 350 検索ｷｰ10     */
 , UNIQ         int IDENTITY(1,1)                                               /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ          varchar           (    1 )      DEFAULT 1   NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET        varchar           (   14 )                                      /* 820 登録日時     */
 , PGSET        varchar           (   10 )                                      /* 830 作成PG       */
 , PGPSET       varchar           (   10 )                                      /* 840 作成親PG     */
 , USRSET       varchar           (   10 )                                      /* 850 作成社員     */
 , DYUPD        varchar           (   14 )                                      /* 860 更新日時     */
 , PGUPD        varchar           (   10 )                                      /* 870 更新PG       */
 , PGPUPD       varchar           (   10 )                                      /* 880 更新親PG     */
 , USRUPD       varchar           (   10 )                                      /* 890 更新者       */
);

==> openGion_core_5.9.20.0.zip: ge/db/sqlserver/sql/install/01_TABLE/GE39S.sql <==
/****************************************************************************/
/* GE39 ( ﾌｧｲﾙ管理ﾃｰﾌﾞﾙ )                                                   */
/*                                                                          */
/* Created : 2017/05/02 11:07:53                                            */
/****************************************************************************/
CREATE TABLE GE39 (
   UNIQ_ID      varchar           (   10 )                  NOT NULL            /*  10 UNIQ番号     */
 , SEQNO        INTEGER                         DEFAULT 0   NOT NULL            /*  20 表示順       */
 , SYSTEM_ID    varchar           (   10 )                  NOT NULL            /*  30 ｼｽﾃﾑID       */
 , SYFILE       varchar           (  100 )                  NOT NULL            /*  40 ﾌｧｲﾙ種別     */
 , REF_KEY      varchar           (  100 )                  NOT NULL            /*  50 関連ｷｰ       */
 , SUFFIX       varchar           (   10 )                                      /*  60 拡張子       */
 , SYNAME       varchar           (  200 )                                      /*  70 種別名称     */
 , SAVE_FOLDER  varchar           (  300 )                                      /*  80 保管ﾌｫﾙﾀﾞ    */
 , FILE_URL     varchar           (  300 )                                      /*  90 ﾌｧｲﾙURL      */
 , ICON_URL     varchar           (  300 )                                      /* 100 ｱｲｺﾝURL      */
 , ROLES        varchar           (  500 )                                      /* 110 ﾛｰﾙｽﾞ        */
 , SU_LMT       INTEGER                         DEFAULT 0   NOT NULL            /* 120 閲覧制限数   */
 , DY_LMT       INTEGER                         DEFAULT 0   NOT NULL            /* 130 閲覧期日     */
 , FGANGO       varchar           (    1 )      DEFAULT '0' NOT NULL            /* 140 暗号化FG     */
 , FGZIP        varchar           (    1 )      DEFAULT '0' NOT NULL            /* 150 圧縮FG       */
 , FILE_NAME    varchar           (  500 )                                      /* 160 ﾌｧｲﾙ名称     */
 , CONTENTS     varchar           ( 4000 )                                      /* 170 内容         */
 , FG_NEW       varchar           (    1 )      DEFAULT '1' NOT NULL            /* 180 最新FG       */
 , SIZE_FILE    INTEGER                         DEFAULT 0   NOT NULL            /* 190 ﾌｧｲﾙｻｲｽﾞ     */
 , DYFILESET    varchar           (   14 )                                      /* 200 ﾌｧｲﾙ登録日時 */
 , USRTOROKU    varchar           (   10 )                                      /* 210 ﾌｧｲﾙ登録者   */
 , SETGUIID     varchar           (   10 )                                      /* 220 登録画面ID   */
 , FGKOSHIN     varchar           (    1 )      DEFAULT '1'                     /* 230 変更許可FG   */
 , FGKOKAI      varchar           (    1 )      DEFAULT '1'                     /* 240 公開許可FG   */
 , SRCHKEY1     varchar           (  500 )                                      /* 250 検索ｷｰ1      */
 , SRCHKEY2     varchar           (  500 )                                      /* 270 検索ｷｰ2      */
 , SRCHKEY3     varchar           (  500 )                                      /* 280 検索ｷｰ3      */
 , SRCHKEY4     varchar           (  500 )                                      /* 290 検索ｷｰ4      */
 , SRCHKEY5     varchar           (  500 )                                      /* 300 検索ｷｰ5      */
 , SRCHKEY6     varchar           (  500 )                                      /* 310 検索ｷｰ6      */
 , SRCHKEY7     varchar           (  500 )                                      /* 320 検索ｷｰ7      */
 , SRCHKEY8     varchar           (  500 )                                      /* 330 検索ｷｰ8      */
 , SRCHKEY9     varchar           (  500 )                                      /* 340 検索ｷｰ9      */
 , SRCHKEY10    varchar           (  500 )                                      /* 350 検索ｷｰ10     */
 , UNIQ         int IDENTITY(1,1)                                               /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ          varchar           (    1 )      DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET        varchar           (   14 )                                      /* 820 登録日時     */
 , PGSET        varchar           (   10 )                                      /* 830 作成PG       */
 , PGPSET       varchar           (   10 )                                      /* 840 作成親PG     */
 , USRSET       varchar           (   10 )                                      /* 850 作成社員     */
 , DYUPD        varchar           (   14 )                                      /* 860 更新日時     */
 , PGUPD        varchar           (   10 )                                      /* 870 更新PG       */
 , PGPUPD       varchar           (   10 )                                      /* 880 更新親PG     */
 , USRUPD       varchar           (   10 )                                      /* 890 更新者       */
);
